@@ -1,6 +1,6 @@
 #!/bin/sh -e
-# check if debmake works as expected
-LC_ALL=en_US.UTF-8
+# tar.gz with project-ver/ in tree debmake -x0 followed by -x3 -B
+LC_ALL=C.UTF-8
 export LC_ALL
 
 # non-native source tree with tar.gz on side
@@ -11,11 +11,11 @@ mkdir ${PROJECT}
 echo "DUMMY ${PROJECT}" > ${PROJECT}/dummy-${PROJECT}
 tar -cvzf ${PROJECT}.tar.gz ${PROJECT}
 cd ${PROJECT} || exit 1
-debmake -x0 2>&1
+debmake -x0
 cd .. || exit 1
 rm -f ${PROJECT}*.tar.?z
 cd ${PROJECT} || exit 1
-debmake -x3 -y -B 2>&1
+debmake -x3 -B
 test -x debian/rules
 cd .. || exit 1
 
