@@ -1,6 +1,6 @@
 #!/bin/sh -e
-# check if debmake works as expected
-LC_ALL=en_US.UTF-8
+# project_ver.orig.tar.xz w/o project-ver/
+LC_ALL=C.UTF-8
 export LC_ALL
 
 # non-native from archive.orig.tar.xz using -a
@@ -12,7 +12,7 @@ mkdir ${PROJECT}
 echo "DUMMY ${PROJECT}" > ${PROJECT}/dummy-${PROJECT}
 tar --xz -cvf ${PROJECTX}.orig.tar.xz ${PROJECT}
 rm -rf ${PROJECT}
-debmake -a ${PROJECTX}.orig.tar.xz 2>&1
+debmake ${PROJECTX}.orig.tar.xz
 cd ${PROJECT} || exit 1
 test -x debian/rules
 cd .. || exit 1
